@@ -26,6 +26,9 @@
 #define GET_WIDGET(x) (_gtk_builder_get_widget (self->priv->builder, (x)))
 
 
+G_DEFINE_TYPE (OAuthAccountChooserDialog, oauth_account_chooser_dialog, GTK_TYPE_DIALOG)
+
+
 enum {
 	ACCOUNT_DATA_COLUMN,
 	ACCOUNT_NAME_COLUMN,
@@ -34,9 +37,6 @@ enum {
 };
 
 
-static gpointer parent_class = NULL;
-
-
 struct _OAuthAccountChooserDialogPrivate {
 	GtkBuilder *builder;
 };
@@ -51,7 +51,7 @@ oauth_account_chooser_dialog_finalize (GObject *object)
 
 	_g_object_unref (self->priv->builder);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (oauth_account_chooser_dialog_parent_class)->finalize (object);
 }
 
 
@@ -60,7 +60,6 @@ oauth_account_chooser_dialog_class_init (OAuthAccountChooserDialogClass *klass)
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (OAuthAccountChooserDialogPrivate));
 
 	object_class = (GObjectClass*) klass;
@@ -163,34 +162,6 @@ oauth_account_chooser_dialog_init (OAuthAccountChooserDialog *self)
 }
 
 
-GType
-oauth_account_chooser_dialog_get_type (void)
-{
-	static GType type = 0;
-
-	if (type == 0) {
-		static const GTypeInfo g_define_type_info = {
-			sizeof (OAuthAccountChooserDialogClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) oauth_account_chooser_dialog_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,
-			sizeof (OAuthAccountChooserDialog),
-			0,
-			(GInstanceInitFunc) oauth_account_chooser_dialog_init,
-			NULL
-		};
-		type = g_type_register_static (GTK_TYPE_DIALOG,
-					       "OAuthAccountChooserDialog",
-					       &g_define_type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 static void
 oauth_account_chooser_dialog_construct (OAuthAccountChooserDialog *self,
 				         GList                      *accounts,
